#The following analyses were carried out using R version 3.4.3

#Clear
rm(list=ls())

#Potentially set working directory (adjust this to your working directory if necessary)
#The directory must contain "analysis_dataset.dta"

#Load packages (versions indicated)
#Make sure to install all packges if not already installed
library(readstata13) #readstata13_0.9.0
library(MCMCpack) #MCMCpack_1.4-1
library(coda) #coda_0.19-1
library(xtable) #xtable_1.8-3

#Load data and subset for responsiveness analyses 
#(i.e. only Austria, every other country yields identical results)
data <- read.dta13("analysis_dataset.dta")
data_responsiveness <- data[data$member_state == "Austria" & is.na(data$Opinion_eu_wide) == FALSE & is.na(data$AdoptionBinary_80pc)== FALSE,]

#Recode as factor
data_responsiveness$EUCompetenceLevel <- as.factor(data_responsiveness$EUCompetenceLevel)
data_responsiveness$Unanimity_enc <- as.factor(data_responsiveness$Unanimity_enc)



################################################
##Main responsiveness analyses on full sample
################################################


#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Produce results for column "Council: equal power" in Table A7.1 in the Supporting Information
means <- summary(model_salient) #Means
HPDI <- round(HPDinterval(model_salient, prob = 0.95), 3) #Highest posterior density intervals
lml <- attr(model_salient, "logmarglike") #Log marginal likelihood
Table_A7_1_C1 <- cbind(means$statistics[,1], HPDI[,1], HPDI[,2]) #Table
colnames(Table_A7_1_C1) <- c("Mean", "HPDI_LOW", "HPDI_HIGH")
print.xtable(xtable(Table_A7_1_C1, digits=c(3, 3, 3, 3), caption = "Column 'Council: equal power' in Table A7.1"), type="html", file="Table_A7_1.html", caption.placement = "top", append = FALSE)
sink("Log_marginal_likelihoods_Table_A7_1.txt")
print("Log marginal likelihood for Column 'Council: equal power' in Table A7.1")
lml[1,1]
sink()

#Investigate traceplots and Geweke statistic
model_salient_plot <- mcmc.list(model_salient)
colnames(model_salient_plot[[1]], do.NULL = FALSE) 
colnames(model_salient_plot[[1]]) <- c("Intercept", "Territorial opinion", "Mixed Competence", "Mainly EU Competence", "Unclear decision rule", "Unanimity")
plot(model_salient_plot)
geweke.diag(model_salient)


#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Produce results for column "Council: unequal power" in Table A7.1 in the Supporting Information
means <- summary(model_power) #Means
HPDI <- round(HPDinterval(model_power, prob = 0.95), 3) #Highest posterior density intervals
lml <- attr(model_power, "logmarglike") #Log marginal likelihood
Table_A7_1_C2 <- cbind(means$statistics[,1], HPDI[,1], HPDI[,2]) #Table
colnames(Table_A7_1_C2) <- c("Mean", "HPDI_LOW", "HPDI_HIGH")
print.xtable(xtable(Table_A7_1_C2, digits=c(3, 3, 3, 3), caption = "Column 'Council: unequal power' in Table A7.1"), type="html", file="Table_A7_1.html", caption.placement = "top", append = TRUE)
sink("Log_marginal_likelihoods_Table_A7_1.txt", append = TRUE)
print("Log marginal likelihood for Column 'Council: unequal power' in Table A7.1")
lml[1,1]
sink()

#Investigate traceplots and Geweke statistic
model_power_plot <- mcmc.list(model_power)
colnames(model_power_plot[[1]], do.NULL = FALSE) 
colnames(model_power_plot[[1]]) <- c("Intercept", "Territorial opinion", "Mixed Competence", "Mainly EU Competence", "Unclear decision rule", "Unanimity")
plot(model_power_plot)
geweke.diag(model_power)


#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Produce results for column "Council-EP/Commission" in Table A7.1 in the Supporting Information
means <- summary(model_ep) #Means
HPDI <- round(HPDinterval(model_ep, prob = 0.95), 3) #Highest posterior density intervals
lml <- attr(model_ep, "logmarglike") #Log marginal likelihood
Table_A7_1_C3 <- cbind(means$statistics[,1], HPDI[,1], HPDI[,2]) #Table
colnames(Table_A7_1_C3) <- c("Mean", "HPDI_LOW", "HPDI_HIGH")
print.xtable(xtable(Table_A7_1_C3, digits=c(3, 3, 3, 3), caption = "Column 'Council-EP/Commission' in Table A7.1"), type="html", file="Table_A7_1.html", caption.placement = "top", append = TRUE)
sink("Log_marginal_likelihoods_Table_A7_1.txt", append = TRUE)
print("Log marginal likelihood for Column 'Council-EP/Commission' in Table A7.1")
lml[1,1]
sink()

#Investigate traceplots and Geweke statistic
model_ep_plot <- mcmc.list(model_ep)
colnames(model_ep_plot[[1]], do.NULL = FALSE) 
colnames(model_ep_plot[[1]]) <- c("Intercept", "Territorial opinion", "Mixed Competence", "Mainly EU Competence", "Unclear decision rule", "Unanimity")
plot(model_ep_plot)
geweke.diag(model_ep)


#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Produce results for column "Standard model" in Table A7.1 in the Supporting Information
means <- summary(model_eu) #Means
HPDI <- round(HPDinterval(model_eu, prob = 0.95), 3) #Highest posterior density intervals
lml <- attr(model_eu, "logmarglike") #Log marginal likelihood
Table_A7_1_C4 <- cbind(means$statistics[,1], HPDI[,1], HPDI[,2]) #Table
colnames(Table_A7_1_C4) <- c("Mean", "HPDI_LOW", "HPDI_HIGH")
print.xtable(xtable(Table_A7_1_C4, digits=c(3, 3, 3, 3), caption = "Column 'Standard model' in Table A7.1"), type="html", file="Table_A7_1.html", caption.placement = "top", append = TRUE)
sink("Log_marginal_likelihoods_Table_A7_1.txt", append = TRUE)
print("Log marginal likelihood for Column 'Standard model' in Table A7.1")
lml[1,1]
sink()

#Investigate traceplots and Geweke statistic
model_eu_plot <- mcmc.list(model_eu)
colnames(model_eu_plot[[1]], do.NULL = FALSE) 
colnames(model_eu_plot[[1]]) <- c("Intercept", "EU-wide opinion", "Mixed EUCompetenceLevel", "Mainly EU EUCompetenceLevel", "Unclear decision rule", "Unanimity")
plot(model_eu_plot)
geweke.diag(model_eu)


#Calculate Bayes factors
#Produce Table 1 in the paper
Table_1_full_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Table_1_full_BF)
#...read last column with 7.41, 5.11 and 8.93 as reported in the paper
#...note that comparisons of territorial models with each other yield no
#...significant differences



#############################################################
##Main responsiveness analyses on sample of conflict issues
#############################################################


#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Produce results for column "Council: equal power" in Table A7.2 in the Supporting Information
means <- summary(model_salient) #Means
HPDI <- round(HPDinterval(model_salient, prob = 0.95), 3) #Highest posterior density intervals
lml <- attr(model_salient, "logmarglike") #Log marginal likelihood
Table_A7_2_C1 <- cbind(means$statistics[,1], HPDI[,1], HPDI[,2]) #Table
colnames(Table_A7_2_C1) <- c("Mean", "HPDI_LOW", "HPDI_HIGH")
print.xtable(xtable(Table_A7_2_C1, digits=c(3, 3, 3, 3), caption = "Column 'Council: equal power' in Table A7.2"), type="html", file="Table_A7_2.html", caption.placement = "top", append = FALSE)
sink("Log_marginal_likelihoods_Table_A7_2.txt")
print("Log marginal likelihood for Column 'Council: equal power' in Table A7.2")
lml[1,1]
sink()

#Investigate traceplots and Geweke statistic
model_salient_plot <- mcmc.list(model_salient)
colnames(model_salient_plot[[1]], do.NULL = FALSE) 
colnames(model_salient_plot[[1]]) <- c("Intercept", "Territorial opinion", "Mixed Competence", "Mainly EU Competence", "Unclear decision rule", "Unanimity")
plot(model_salient_plot)
geweke.diag(model_salient)


#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Produce results for column "Council: unequal power" in Table A7.2 in the Supporting Information
means <- summary(model_power) #Means
HPDI <- round(HPDinterval(model_power, prob = 0.95), 3) #Highest posterior density intervals
lml <- attr(model_power, "logmarglike") #Log marginal likelihood
Table_A7_2_C2 <- cbind(means$statistics[,1], HPDI[,1], HPDI[,2]) #Table
colnames(Table_A7_2_C2) <- c("Mean", "HPDI_LOW", "HPDI_HIGH")
print.xtable(xtable(Table_A7_2_C2, digits=c(3, 3, 3, 3), caption = "Column 'Council: unequal power' in Table A7.2"), type="html", file="Table_A7_2.html", caption.placement = "top", append = TRUE)
sink("Log_marginal_likelihoods_Table_A7_2.txt", append = TRUE)
print("Log marginal likelihood for Column 'Council: unequal power' in Table A7.2")
lml[1,1]
sink()

#Investigate traceplots and Geweke statistic
model_power_plot <- mcmc.list(model_power)
colnames(model_power_plot[[1]], do.NULL = FALSE) 
colnames(model_power_plot[[1]]) <- c("Intercept", "Territorial opinion", "Mixed Competence", "Mainly EU Competence", "Unclear decision rule", "Unanimity")
plot(model_power_plot)
geweke.diag(model_power)


#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Produce results for column "Council-EP/Commission" in Table A7.2 in the Supporting Information
means <- summary(model_ep) #Means
HPDI <- round(HPDinterval(model_ep, prob = 0.95), 3) #Highest posterior density intervals
lml <- attr(model_ep, "logmarglike") #Log marginal likelihood
Table_A7_2_C3 <- cbind(means$statistics[,1], HPDI[,1], HPDI[,2]) #Table
colnames(Table_A7_2_C3) <- c("Mean", "HPDI_LOW", "HPDI_HIGH")
print.xtable(xtable(Table_A7_2_C3, digits=c(3, 3, 3, 3), caption = "Column 'Council-EP/Commission' in Table A7.2"), type="html", file="Table_A7_2.html", caption.placement = "top", append = TRUE)
sink("Log_marginal_likelihoods_Table_A7_2.txt", append = TRUE)
print("Log marginal likelihood for Column 'Council-EP/Commission' in Table A7.2")
lml[1,1]
sink()

#Investigate traceplots and Geweke statistic
model_ep_plot <- mcmc.list(model_ep)
colnames(model_ep_plot[[1]], do.NULL = FALSE) 
colnames(model_ep_plot[[1]]) <- c("Intercept", "Territorial opinion", "Mixed Competence", "Mainly EU Competence", "Unclear decision rule", "Unanimity")
plot(model_ep_plot)
geweke.diag(model_ep)


#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Produce results for column "Standard model" in Table A7.2 in the Supporting Information
means <- summary(model_eu) #Means
HPDI <- round(HPDinterval(model_eu, prob = 0.95), 3) #Highest posterior density intervals
lml <- attr(model_eu, "logmarglike") #Log marginal likelihood
Table_A7_2_C4 <- cbind(means$statistics[,1], HPDI[,1], HPDI[,2]) #Table
colnames(Table_A7_2_C4) <- c("Mean", "HPDI_LOW", "HPDI_HIGH")
print.xtable(xtable(Table_A7_2_C4, digits=c(3, 3, 3, 3), caption = "Column 'Standard model' in Table A7.2"), type="html", file="Table_A7_2.html", caption.placement = "top", append = TRUE)
sink("Log_marginal_likelihoods_Table_A7_2.txt", append = TRUE)
print("Log marginal likelihood for Column 'Standard model' in Table A7.2")
lml[1,1]
sink()

#Investigate traceplots and Geweke statistic
model_eu_plot <- mcmc.list(model_eu)
colnames(model_eu_plot[[1]], do.NULL = FALSE) 
colnames(model_eu_plot[[1]]) <- c("Intercept", "EU-wide opinion", "Mixed EUCompetenceLevel", "Mainly EU EUCompetenceLevel", "Unclear decision rule", "Unanimity")
plot(model_eu_plot)
geweke.diag(model_eu)


#Calculate Bayes factors
#Produce Table 1 in the paper
Table_1_conflict_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Table_1_conflict_BF)
#...read last column with 26.7, 22.2 and 36.6 as reported in the paper
#...note that comparisons of territorial models with each other yield no
#...significant differences

#Print Bayes factors for Table 1 in the paper
Table_1_full <- rbind(Table_1_full_BF$BF.mat[1:3,4])
Table_1_conflict <- rbind(Table_1_conflict_BF$BF.mat[1:3,4])
rownames(Table_1_full) <- c("Bayes factors")
rownames(Table_1_conflict) <- c("Bayes factors")
colnames(Table_1_full) <- c("Council: equal power", "Council: unequal power", "Council-EP/Commission")
colnames(Table_1_conflict) <- c("Council: equal power", "Council: unequal power", "Council-EP/Commission")
print.xtable(xtable(Table_1_full, digits=c(2, 2, 2, 2), caption = "Bayes factor results on full sample"), type="html", file="Table_1_BF.html", caption.placement = "top", append = FALSE)
print.xtable(xtable(Table_1_conflict, digits=c(1, 1, 1, 1), caption = "Bayes factor results on sample of conflict issues"), type="html", file="Table_1_BF.html", caption.placement = "top", append = TRUE)



########################################################
##Main responsiveness analyses with alternative priors
########################################################


#The following section just repeats all analyses from above two times.
#The b0 prior is changed to gauge the sensitivity of results towards
#the choice of alternative priors. In the first set of analyses, b0 = 100.
#In the second set of analyses, b0 = -100. The results are substantively
#unchanged. This is reported in the Supporting Information in section 7). 


#####Main responsiveness analyses on full sample: b0 = 100#####

#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Calculate Bayes factors
Prior_full_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Prior_full_BF)


#####Main responsiveness analyses on sample of conflict issues: b0 = 100#####

#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Calculate Bayes factors
Prior_conflict_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Prior_conflict_BF)


#####Main responsiveness analyses on full sample: b0 = -100#####

#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=-100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=-100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=-100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=-100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Calculate Bayes factors
Prior_full_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Prior_full_BF)


#####Main responsiveness analyses on sample of conflict issues: b0 = -100#####

#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=-100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=-100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=-100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=-100, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Calculate Bayes factors
Prior_conflict_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Prior_conflict_BF)



##############################################################
##Alternative responsiveness analyses with different samples
##############################################################
  
#In the following, we re-estimate the models and Bayes factors for
#three alternative definitions of conflict issues resulting in alternative
#sample sizes. These results are reported in section 7) in the Supporting
#Information.

######More than 5 percent of national publics dissenting#####

#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.05,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.05,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.05,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.05,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Calculate Bayes factors
#Produce Table A9 in the Supporting Information, upper part
Table_A9_conflict5_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Table_A9_conflict5_BF)
#...read last column with 9.69, 7.08 and 13.34 as reported in the Supporting Information


######More than 10 percent of national publics dissenting#####

#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.10,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.10,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.10,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.10,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Calculate Bayes factors
#Produce Table A9 in the Supporting Information, middle part
Table_A9_conflict10_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Table_A9_conflict10_BF)
#...read last column with 7.74, 5.91 and 10.09 as reported in the Supporting Information


######More than 20 percent of national publics dissenting#####

#Estimate "Council: equal power" specification
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.20,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council: unequal power" specification
model_power <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_power_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.20,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Council-EP/Commission" specification
model_ep <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_EP_COM_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.20,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Estimate "Standard model" with EU-wide opinion
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.20,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)

#Calculate Bayes factors
#Produce Table A9 in the Supporting Information, lower part
Table_A9_conflict20_BF <- BayesFactor(model_salient, model_power, model_ep, model_eu)
summary(Table_A9_conflict20_BF)
#...read last column with 22.1, 26.3 and 37.6 as reported in the Supporting Information

#Print Bayes factors for Table A9 in the Supporting Information
Table_A9 <- rbind(Table_A9_conflict5_BF$BF.mat[1:3,4], Table_A9_conflict10_BF$BF.mat[1:3,4], Table_A9_conflict20_BF$BF.mat[1:3,4])
rownames(Table_A9) <- c("Bayes factors (>5% dissenting)", "Bayes factors (>10% dissenting)", "Bayes factors (>20% dissenting)")
colnames(Table_A9) <- c("Council: equal power", "Council: unequal power", "Council-EP/Commission")
print.xtable(xtable(Table_A9, digits=c(2, 2, 2, 2), caption = "Bayes factor results"), type="html", file="Table_A9_BF.html", caption.placement = "top", append = FALSE)



#####################
##Robustness checks
#####################

#This section calculates the Bayes factors for the robustness checks reported in
#section 9) in the Supporting Information.

#####Responsiveness analyses - full sample#####

#Note that only the Bayes factor results are reported in the Supporting Information

#Produce results for Model A-R1 in Table A13, upper part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted_raw + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R1_full <- BayesFactor(model_eu, model_salient)
summary(BF_R1_full)

#Produce results for Model A-R2 in Table A13, upper part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_50pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_50pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R2_full <- BayesFactor(model_eu, model_salient)
summary(BF_R2_full)

#Produce results for Model A-R3 in Table A13, upper part, in the Supporting Information
#...estimate both models
model_eu <- MCMCregress(AdoptionDegree~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMCregress(AdoptionDegree~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R3_full <- BayesFactor(model_eu, model_salient)
summary(BF_R3_full)

#Produce results for Model A-R4 in Table A13, upper part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$Problem == "No",], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$Problem == "No",], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R4_full <- BayesFactor(model_eu, model_salient)
summary(BF_R4_full)

#Produce results for Model A-R5 in Table A13, upper part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$FlippedOpinion == "No",], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$FlippedOpinion == "No",], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R5_full <- BayesFactor(model_eu, model_salient)
summary(BF_R5_full)

#Produce results for Model A-R6 in Table A13, upper part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_5halfyears~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_5halfyears~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R6_full <- BayesFactor(model_eu, model_salient)
summary(BF_R6_full)

#Produce results for Model A-R7 in Table A13, upper part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_5years~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_5years~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness, marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R7_full <- BayesFactor(model_eu, model_salient)
summary(BF_R7_full)

#Print Bayes factors for Table A13, upper part, in the Supporting Information
Table_A13_1 <- cbind(BF_R1_full$BF.mat[2,1], BF_R2_full$BF.mat[2,1], BF_R3_full$BF.mat[2,1], BF_R4_full$BF.mat[2,1], BF_R5_full$BF.mat[2,1], BF_R6_full$BF.mat[2,1], BF_R7_full$BF.mat[2,1])
rownames(Table_A13_1) <- c("Bayes factors")
colnames(Table_A13_1) <- c("Model A-R1", "Model A-R2", "Model A-R3", "Model A-R4", "Model A-R5", "Model A-R6", "Model A-R7")
print.xtable(xtable(Table_A13_1, digits=c(2, 2, 1, 2, 2, 2, 2, 2), caption = "Bayes factor results on full sample"), type="html", file="Table_A13_BF.html", caption.placement = "top", append = FALSE)



#####Responsiveness analyses - sample of conflict issues#####

#Note that only the Bayes factor results are reported in the Supporting Information

#Produce results for Model A-R1 in Table A13, lower part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted_raw + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R1_conflict <- BayesFactor(model_eu, model_salient)
summary(BF_R1_conflict)

#Produce results for Model A-R2 in Table A13, lower part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_50pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_50pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R2_conflict <- BayesFactor(model_eu, model_salient)
summary(BF_R2_conflict)

#Produce results for Model A-R3 in Table A13, lower part, in the Supporting Information
#...estimate both models
model_eu <- MCMCregress(AdoptionDegree~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMCregress(AdoptionDegree~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R3_conflict <- BayesFactor(model_eu, model_salient)
summary(BF_R3_conflict)

#Produce results for Model A-R4 in Table A13, lower part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$Problem == "No" & data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$Problem == "No" & data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R4_conflict <- BayesFactor(model_eu, model_salient)
summary(BF_R4_conflict)

#Produce results for Model A-R5 in Table A13, lower part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_80pc~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$FlippedOpinion == "No" & data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_80pc~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$FlippedOpinion == "No" & data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R5_conflict <- BayesFactor(model_eu, model_salient)
summary(BF_R5_conflict)

#Produce results for Model A-R6 in Table A13, lower part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_5halfyears~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_5halfyears~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R6_conflict <- BayesFactor(model_eu, model_salient)
summary(BF_R6_conflict)

#Produce results for Model A-R7 in Table A13, lower part, in the Supporting Information
#...estimate both models
model_eu <- MCMClogit(AdoptionBinary_5years~Opinion_eu_wide + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
model_salient <- MCMClogit(AdoptionBinary_5years~Opinion_salience_weighted + EUCompetenceLevel + Unanimity_enc, b0=0, B0=.001, mcmc=100000, thin = 20, data=data_responsiveness[data_responsiveness$conflict_perc > 0.15,], marginal.likelihood = "Laplace", verbose=1, tune = 1.1)
#...calculate Bayes factor
BF_R7_conflict <- BayesFactor(model_eu, model_salient)
summary(BF_R7_conflict)

#Print Bayes factors for Table A13, lower part, in the Supporting Information
Table_A13_2 <- cbind(BF_R1_conflict$BF.mat[2,1], BF_R2_conflict$BF.mat[2,1], BF_R3_conflict$BF.mat[2,1], BF_R4_conflict$BF.mat[2,1], BF_R5_conflict$BF.mat[2,1], BF_R6_conflict$BF.mat[2,1], BF_R7_conflict$BF.mat[2,1])
rownames(Table_A13_2) <- c("Bayes factors")
colnames(Table_A13_2) <- c("Model A-R1", "Model A-R2", "Model A-R3", "Model A-R4", "Model A-R5", "Model A-R6", "Model A-R7")
print.xtable(xtable(Table_A13_2, digits=c(1, 1, 1, 2, 1, 1, 1, 1), caption = "Bayes factor results on sample of conflict issues"), type="html", file="Table_A13_BF.html", caption.placement = "top", append = TRUE)


