////////////////////////
////////////////////////
//MAIN ANALYSES/////////
////////////////////////
////////////////////////

//The following analyses were carried out using STATA/IC 15.1

//This script performs the main analyses reported in the article and the Supporting Information

/*Potentially set working directory. This directory must contain:
1. "analysis_dataset.dta"
*/

//Uncomment the following line if you have not installed the "unique" command
//ssc install unique

//Load analysis dataset
use "analysis_dataset.dta", clear



///////////////////////////////////////////////
//Main responsiveness analyses on full sample
///////////////////////////////////////////////


//Note that all responsiveness models are run by selecting the observations for Austria,
//any other country will yield identical results

//Correlation between public opinion measures used in responsiveness analyses
corr Opinion_eu_wide  Opinion_salience_weighted Opinion_salience_power_weighted Opinion_salience_EP_COM_weighted if member_state == 1 & AdoptionBinary_80pc != . 
corr Opinion_eu_wide  Opinion_salience_weighted Opinion_salience_power_weighted Opinion_salience_EP_COM_weighted if member_state == 1 & AdoptionBinary_80pc != . & conflict_perc > 0.15
//...as reported in the article in section "Assessing Responsiveness and Congruence"

//Estimate "Council: equal power" specification 
logit AdoptionBinary_80pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
outreg using "Table_A6_1.doc", replace starlevels(5 1) se
unique QuestionN if e(sample) == 1
//...reported as model "Council: equal power" in Table A6.1 in the Supporting Information

//Produce Figure 1 in the article
margins, at( Opinion_salience_weighted = (0 (0.02) 1))
marginsplot, scheme(lean2) recast(line) recastci(rline) yline(0.5, lcolor(gs8) lwidth(thin)) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) ytitle("Probability of policy change") xtitle("Salience-weighted opinion" "('Council: equal power' specification)") title("") xlabel(0.1 "10%" 0.2 "20%" 0.3 "30%" 0.4 "40%" 0.5 "50%" 0.6 "60%" 0.7 "70%" 0.8 "80%" 0.9 "90%") ylabel(0 (0.1) 0.9)
graph export "Figure_1.png", replace height(1500) 
//...note that some figures from the "margins" command are mentioned in the article in section "Assessing Responsiveness and Congruence"

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)

//Calculate predicted probabilities if salience-weighted estimates were valid for EU-wide opinion 
gen aux_territorial =  Opinion_salience_weighted
replace  Opinion_salience_weighted = Opinion_eu_wide
predict xb_salient_counterfactual
replace  Opinion_salience_weighted = aux_territorial
//...this is relevant for section 10) in the Supporting Information

//Estimate "Council: unequal power" specification 
logit AdoptionBinary_80pc Opinion_salience_power_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
outreg using "Table_A6_1.doc", merge starlevels(5 1) se
unique QuestionN if e(sample) == 1
//...reported as model "Council: unequal power" in Table A6.1 in the Supporting Information

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_power
gen lnf_power = AdoptionBinary_80pc*log(xb_power) + (1-AdoptionBinary_80pc)*log(1-xb_power)

//Estimate "Council-EP/Commission" specification
logit AdoptionBinary_80pc Opinion_salience_EP_COM_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
outreg using "Table_A6_1.doc", merge starlevels(5 1) se
unique QuestionN if e(sample) == 1
//...reported as model "Council-EP/Commission" in Table A6.1 in the Supporting Information

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_ep
gen lnf_ep = AdoptionBinary_80pc*log(xb_ep) + (1-AdoptionBinary_80pc)*log(1-xb_ep)

//Estimate "Standard model" with EU-wide opinion
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
outreg using "Table_A6_1.doc", merge starlevels(5 1) se
unique QuestionN if e(sample) == 1
//...reported as model "Standard model" in Table A6.1 in the Supporting Information

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)

//Test for the possibility that responsiveness may be moderated by EU-wide salience 
logit AdoptionBinary_80pc c.Salience_eu_wide##c.Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
//...interaction term is indistinguishable from zero as reported in section 7) in the Supporting Information

//Investigate whether differences in log-likelihoods are mesokurtic
//Produce Figure A3.1 in the Supporting Information
gen lnf_diff1 = lnf_eu - lnf_salient
kdensity lnf_diff1 if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
graph export "Figure_A3_1.png", replace height(1500) 

//Produce Figure A3.2 in the Supporting Information
gen lnf_diff2 = lnf_eu - lnf_power
kdensity lnf_diff2 if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
graph export "Figure_A3_2.png", replace height(1500) 

//Produce Figure A3.3 in the Supporting Information
gen lnf_diff3 = lnf_eu - lnf_ep
kdensity lnf_diff3 if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
graph export "Figure_A3_3.png", replace height(1500) 

//Perform Clarke tests
//Produce Table 1 in the article, upper part, column "Council: equal power"
signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1

//Produce Table 1 in the article, upper part, column "Council: unequal power"
signtest lnf_eu = lnf_power if member_state == 1 & e(sample) == 1

//Produce Table 1 in the article, upper part, column "Council-EP/Commission"
signtest lnf_eu = lnf_ep if member_state == 1 & e(sample) == 1

//Test specifications of the territorial model against each other
signtest lnf_ep = lnf_salient if member_state == 1 & e(sample) == 1
signtest lnf_power = lnf_salient if member_state == 1 & e(sample) == 1
signtest lnf_ep = lnf_power if member_state == 1 & e(sample) == 1
//...relevant for assessments mentioned in the article in section "Assessing Responsiveness and Congruence"

//Investigate differences in predicted probabilities between standard model and "Council: equal power" specification
gen difference_pred_probs_salient = abs(xb_salient - xb_eu)
sum difference_pred_probs_salient if e(sample) == 1, detail 
//...mean of 2 percentage points as reported in the article in section "Does Territorial Representation Make A Difference?"

//Investigate differences in predicted probabilities when plugging in EU-wide vs. salience-weighted opinion, 
//assuming "Council: equal power" specification is correct
gen difference_pred_cf_territorial = abs(xb_salient - xb_salient_counterfactual)
sum difference_pred_cf_territorial if e(sample) == 1, detail 
//...mean of 1.9 percentage points as reported in section 10) in the Supporting Information

//Investigate differences in binary classifications
//Standard model vs. "Council: equal power" specification
gen bin_salient = .
replace bin_salient = 1 if xb_salient > 0.5
replace bin_salient = 0 if xb_salient <= 0.5
gen bin_eu = .
replace bin_eu = 1 if xb_eu > 0.5
replace bin_eu = 0 if xb_eu <= 0.5
tab bin_salient bin_eu if e(sample) == 1
dis (6+2)/250
//...3.2 percent as reported in section 10) in the Supporting Information

//"Council: equal power" specification plugging in EU-wide vs. salience-weighted opinion
gen bin_salient_cf = .
replace bin_salient_cf = 1 if xb_salient_counterfactual > 0.5
replace bin_salient_cf = 0 if xb_salient_counterfactual <= 0.5
tab bin_salient_cf bin_salient if e(sample) == 1
dis (7+3)/250
//...4 percent as reported in section 10) in the Supporting Information

//Drop variables not needed anymore
drop lnf* xb* difference_pred* bin*



/////////////////////////////////////////////////////////////
//Main responsiveness analyses on sample of conflict issues
/////////////////////////////////////////////////////////////


//Estimate "Council: equal power" specification
logit AdoptionBinary_80pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
outreg using "Table_A6_2.doc", replace starlevels(5 1) se
unique QuestionN if e(sample) == 1
//...reported as model "Council: equal power" in Table A6.2 in the Supporting Information

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)

//Calculate predicted probabilities if salience-weighted estimates were valid for EU-wide opinion 
replace  Opinion_salience_weighted = Opinion_eu_wide 
predict xb_salient_counterfactual
replace  Opinion_salience_weighted = aux_territorial
//...this is relevant for section 10) in the Supporting Information

//Estimate "Council: unequal power" specification
logit AdoptionBinary_80pc Opinion_salience_power_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
outreg using "Table_A6_2.doc", merge starlevels(5 1) se
unique QuestionN if e(sample) == 1
//...reported as model "Council: unequal power" in Table A6.2 in the Supporting Information

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_power
gen lnf_power = AdoptionBinary_80pc*log(xb_power) + (1-AdoptionBinary_80pc)*log(1-xb_power)

//Estimate "Council-EP/Commission" specification
logit AdoptionBinary_80pc Opinion_salience_EP_COM_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
outreg using "Table_A6_2.doc", merge starlevels(5 1) se
unique QuestionN if e(sample) == 1
//...reported as model "Council-EP/Commission" in Table A6.2 in the Supporting Information

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_ep
gen lnf_ep = AdoptionBinary_80pc*log(xb_ep) + (1-AdoptionBinary_80pc)*log(1-xb_ep)

//Estimate "Standard model" with EU-wide opinion
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
outreg using "Table_A6_2.doc", merge starlevels(5 1) se
unique QuestionN if e(sample) == 1
//...reported as model "Standard model" in Table A6.2 in the Supporting Information

//Estimate effect of public opinion in terms of predicted probabilities
margins, dydx(Opinion_eu_wide)
//...2.37 percentage points for one percentage point increase in opinion,
//relevant for back-of-the-envelope calculations in the article in section
//"Does Territorial Representation Make A Difference?"

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)

//Investigate whether differences in log-likelihoods are mesokurtic
//Produce Figure A3.4 in the Supporting Information
gen lnf_diff1 = lnf_eu - lnf_salient
kdensity lnf_diff1 if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
graph export "Figure_A3_4.png", replace height(1500) 

//Produce Figure A3.5 in the Supporting Information
gen lnf_diff2 = lnf_eu - lnf_power
kdensity lnf_diff2 if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
graph export "Figure_A3_5.png", replace height(1500) 

//Produce Figure A3.6 in the Supporting Information
gen lnf_diff3 = lnf_eu - lnf_ep
kdensity lnf_diff3 if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
graph export "Figure_A3_6.png", replace height(1500)

//Perform Clarke tests
//Produce Table 1 in the article, lower part, column "Council: equal power"
signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1

//Produce Table 1 in the article, lower part, column "Council: unequal power"
signtest lnf_eu = lnf_power if member_state == 1 & e(sample) == 1

//Produce Table 1 in the article, lower part, column "Council-EP/Commission"
signtest lnf_eu = lnf_ep if member_state == 1 & e(sample) == 1

//Test specifications of the territorial model against each other
signtest lnf_ep = lnf_salient if member_state == 1 & e(sample) == 1
signtest lnf_power = lnf_salient if member_state == 1 & e(sample) == 1
signtest lnf_ep = lnf_power if member_state == 1 & e(sample) == 1
//...relevant for assessments mentioned in the article in section "Assessing Responsiveness and Congruence"

//Investigate differences in predicted probabilities between standard model and "Council: equal power" specification
gen difference_pred_probs_salient = abs(xb_salient - xb_eu)
sum difference_pred_probs_salient if e(sample) == 1, detail 
//...mean of 7.9 percentage points as reported in the article in section "Does Territorial Representation Make A Difference?"

//Produce Table 3 in the article (cannot be exported at present)
gsort- difference_pred_probs_salient
list QuestionN xb_salient xb_eu AdoptionBinary_80pc question_id if difference_pred_probs_salient > .15 & difference_pred_probs_salient != . & e(sample) == 1

//Investigate differences in predicted probabilities when plugging in EU-wide vs. salience-weighted opinion, 
//assuming "Council: equal power" specification is correct
gen difference_pred_cf_territorial = abs(xb_salient - xb_salient_counterfactual)
sum difference_pred_cf_territorial if e(sample) == 1, detail 
//...mean of 12 percentage points as reported in section 10) in the Supporting Information

//Show cases with more than 30 percentage points difference, relevant for section 10) in the Supporting information
gsort- difference_pred_cf_territorial
list QuestionN xb_salient xb_salient_counterfactual AdoptionBinary_80pc question_id if difference_pred_cf_territorial > .30 & difference_pred_cf_territorial != . & e(sample) == 1

//Investigate differences in binary classifications
//Standard model vs. "Council: equal power" specification
gen bin_salient = .
replace bin_salient = 1 if xb_salient > 0.5
replace bin_salient = 0 if xb_salient <= 0.5
gen bin_eu = .
replace bin_eu = 1 if xb_eu > 0.5
replace bin_eu = 0 if xb_eu <= 0.5
tab bin_salient bin_eu if e(sample) == 1
dis (4 + 4)/72
//...11.1 percent as reported in section 10) in the Supporting Information

//"Council: equal power" specification plugging in EU-wide vs. salience-weighted opinion
gen bin_salient_cf = .
replace bin_salient_cf = 1 if xb_salient_counterfactual > 0.5
replace bin_salient_cf = 0 if xb_salient_counterfactual <= 0.5
tab bin_salient_cf bin_salient if e(sample) == 1
dis (7 + 4)/72
//...15.3 percent as reported in section 10) in the Supporting Information

//Compare to the difference changes in public opinion make for binary classifications
//Create measures that shift public opinion by plus/minus 3 percentage points
//Make sure that the standard model was the last model estimated as in this script (!!!)
gen aux_standard = Opinion_eu_wide 
replace Opinion_eu_wide = Opinion_eu_wide + 0.03
predict xb_opinion_plus
replace Opinion_eu_wide = aux_standard
replace Opinion_eu_wide = Opinion_eu_wide - 0.03
predict xb_opinion_minus
replace Opinion_eu_wide = aux_standard
//Compare binary classifications
gen bin_opinion_plus = .
replace bin_opinion_plus = 1 if xb_opinion_plus > 0.5
replace bin_opinion_plus = 0 if xb_opinion_plus <= 0.5
gen bin_opinion_minus = .
replace bin_opinion_minus = 1 if xb_opinion_minus > 0.5
replace bin_opinion_minus = 0 if xb_opinion_minus <= 0.5
tab bin_eu bin_opinion_plus if e(sample) == 1
dis 8/72
tab bin_eu bin_opinion_minus if e(sample) == 1
dis 6/72
//...11.1 and 8.3 percent as reported in section 10) in the Supporting Information

//Drop variables not needed anymore
drop lnf* xb* difference_pred* bin*



////////////////////////////////////////////////////////////////////
//Alternative responsiveness analyses with both variables included
////////////////////////////////////////////////////////////////////


/*In the following models we include two public opinion measures at the same time.
This alternative specification is discussed in the article in section "Assessing 
Responsiveness and Congruence" and reported in the Supporting Information in 
section 7)*/

//Estimate "Council: equal power" specification
//On full sample
logit AdoptionBinary_80pc  Opinion_salience_weighted Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 
outreg using "Table_A8.doc", replace starlevels(5 1) se
//On sample of conflict issues
logit AdoptionBinary_80pc  Opinion_salience_weighted Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
outreg using "Table_A8.doc", merge starlevels(5 1) se
//...reported as models "Council: equal power" in Table A8 in the Supporting Information

//Estimate "Council: unequal power" specification
//On full sample
logit AdoptionBinary_80pc Opinion_salience_power_weighted Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 
outreg using "Table_A8.doc", merge starlevels(5 1) se
//On sample of conflict issues
logit AdoptionBinary_80pc Opinion_salience_power_weighted Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
outreg using "Table_A8.doc", merge starlevels(5 1) se
//...reported as models "Council: unequal power" in Table A8 in the Supporting Information

//Estimate "Council-EP/Commission" specification
//On full sample
logit AdoptionBinary_80pc Opinion_salience_EP_COM_weighted Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 
outreg using "Table_A8.doc", merge starlevels(5 1) se
//On sample of conflict issues
logit AdoptionBinary_80pc Opinion_salience_EP_COM_weighted Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
outreg using "Table_A8.doc", merge starlevels(5 1) se
//...reported as models "Council: unequal power" in Table A8 in the Supporting Information



//////////////////////////////////////////////////////////////
//Alternative responsiveness analyses with different samples
//////////////////////////////////////////////////////////////


/*In the following, we re-estimate the models and Clarke tests for
three alternative definitions of conflict issues resulting in alternative
sample sizes. These results are reported in section 7) in the Supporting
Information*/


//*****More than 5 percent of national publics dissenting*****

//Estimate "Council: equal power" specification
logit AdoptionBinary_80pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.05

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)


//Estimate "Council: unequal power" specification
logit AdoptionBinary_80pc Opinion_salience_power_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.05

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_power
gen lnf_power = AdoptionBinary_80pc*log(xb_power) + (1-AdoptionBinary_80pc)*log(1-xb_power)


//Estimate "Council-EP/Commission" specification
logit AdoptionBinary_80pc Opinion_salience_EP_COM_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.05

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_ep
gen lnf_ep = AdoptionBinary_80pc*log(xb_ep) + (1-AdoptionBinary_80pc)*log(1-xb_ep)


//Estimate "Standard model" with EU-wide opinion
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.05

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)


//Perform Clarke tests
//Produce Table A9 in the Supporting Information, upper part, column "Council: equal power"
signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1

//Produce Table A9 in the Supporting Information, upper part, column "Council: unequal power"
signtest lnf_eu = lnf_power if member_state == 1 & e(sample) == 1

//Produce Table A9 in the Supporting Information, upper part, column "Council-EP/Commission"
signtest lnf_eu = lnf_ep if member_state == 1 & e(sample) == 1


//Drop variables not needed anymore
drop lnf* xb* 


//*****More than 10 percent of national publics dissenting*****

//Estimate "Council: equal power" specification
logit AdoptionBinary_80pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.10

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)


//Estimate "Council: unequal power" specification
logit AdoptionBinary_80pc Opinion_salience_power_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.10

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_power
gen lnf_power = AdoptionBinary_80pc*log(xb_power) + (1-AdoptionBinary_80pc)*log(1-xb_power)


//Estimate "Council-EP/Commission" specification
logit AdoptionBinary_80pc Opinion_salience_EP_COM_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.10

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_ep
gen lnf_ep = AdoptionBinary_80pc*log(xb_ep) + (1-AdoptionBinary_80pc)*log(1-xb_ep)


//Estimate "Standard model" with EU-wide opinion
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.10

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)


//Perform Clarke tests
//Produce Table A9 in the Supporting Information, middle part, column "Council: equal power"
signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1

//Produce Table A9 in the Supporting Information, middle part, column "Council: unequal power"
signtest lnf_eu = lnf_power if member_state == 1 & e(sample) == 1

//Produce Table A9 in the Supporting Information, middle part, column "Council-EP/Commission"
signtest lnf_eu = lnf_ep if member_state == 1 & e(sample) == 1


//Drop variables not needed anymore
drop lnf* xb* 


//*****More than 20 percent of national publics dissenting*****

//Estimate "Council: equal power" specification
logit AdoptionBinary_80pc Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.20

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)


//Estimate "Council: unequal power" specification
logit AdoptionBinary_80pc Opinion_salience_power_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.20

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_power
gen lnf_power = AdoptionBinary_80pc*log(xb_power) + (1-AdoptionBinary_80pc)*log(1-xb_power)


//Estimate "Council-EP/Commission" specification
logit AdoptionBinary_80pc Opinion_salience_EP_COM_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.20

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_ep
gen lnf_ep = AdoptionBinary_80pc*log(xb_ep) + (1-AdoptionBinary_80pc)*log(1-xb_ep)


//Estimate "Standard model" with EU-wide opinion
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.20

//Calculate observation-specific log-likelihoods for Clarke test
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)


//Perform Clarke tests
//Produce Table A9 in the Supporting Information, lower part, column "Council: equal power"
signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1

//Produce Table A9 in the Supporting Information, lower part, column "Council: unequal power"
signtest lnf_eu = lnf_power if member_state == 1 & e(sample) == 1

//Produce Table A9 in the Supporting Information, lower part, column "Council-EP/Commission"
signtest lnf_eu = lnf_ep if member_state == 1 & e(sample) == 1


//Drop variables not needed anymore
drop lnf* xb* 



////////////////////////////
//Main congruence analyses
////////////////////////////

//Average congruence
tab Congruent_80pc
//...mean of 57 percent as reported in the article in section "Assessing Responsiveness and Congruence"

//Correlation between public opinion and salience measures used in congruence analyses
corr Opinion_majority Opinion_majority_eu_wide if Congruent_80pc != .
corr Salience Salience_eu_wide if Congruent_80pc != .
//...0.82 and 0.69 as reported in the article in section "Assessing Responsiveness and Congruence"

//Produce results for Model 1 in Table 2 in the article
logit Congruent_80pc c.Opinion_majority##c.Salience i.question_id i.member_state
outreg using "Table_2.doc", replace starlevels(5 1) se
unique question_id if e(sample)

//Produce Figure 2 in the article
margins, at(Salience = (0.75 (0.05) 1) Opinion_majority = (0 (0.05) 0.5))
marginsplot, scheme(lean2) bydimension(Salience, label("25% DK/Refusal" "20% DK/Refusal" "15% DK/Refusal" "10% DK/Refusal" "5% DK/Refusal" "0% DK/Refusal")) byopt(title("") compact) recast(line) recastci(rline) yline(0.5, lcolor(gs8) lwidth(thin)) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Opinion majority size") ytitle("Probability of" "policy congruence with opinion") xlabel(0.05 "55%" 0.15 "65%" 0.25 "75%" 0.35 "85%" 0.45 "95%")
graph export "Figure_2.png", replace height(1500) 
//...note that some of the predicted probabilities from the "margins" command above are also mentioned in the article

//Produce results for Model 2 in Table 2 in the article
logit Congruent_80pc c.Opinion_majority##c.Salience i.question_id i.member_state if conflict_perc > 0.15
outreg using "Table_2.doc", merge starlevels(5 1) se
unique question_id if e(sample)

//Produce results for Model 3 in Table 2 in the article
xtset question_id
xtlogit Congruent_80pc c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc i.member_state, re  
outreg using "Table_2.doc", merge starlevels(5 1) se



///////////////////////////////////
//Alternative congruence analyses 
///////////////////////////////////


/*The following analyses operationalize the alternative specifications of the
territorial model as well as congruence according to whether policy change occurred
or not. The results are reported in section 8) in the Supporting Information*/


//Produce Table A10 in the Supporting Information, column "Council: equal power"
xtset question_id
xtlogit Congruent_80pc c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc, re  
outreg using "Table_A10.doc", replace starlevels(5 1) se

//Produce Table A10 in the Supporting Information, column "Council: unequal power"
xtlogit Congruent_80pc c.votes##c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc, re  
outreg using "Table_A10.doc", merge starlevels(5 1) se

//Produce Table A10 in the Supporting Information, column "Council-EP/Commission"
gen unanimity_alt = 0
replace unanimity_alt = 1 if Unanimity_enc == 3
label variable unanimity_alt "Binary Indicator for Unanimity Decision Rule"
xtlogit Congruent_80pc unanimity_alt##c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc, re  
outreg using "Table_A10.doc", merge starlevels(5 1) se


//Produce Table A11
xtlogit Congruent_80pc AdoptionBinary_80pc##c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc, re  
outreg using "Table_A11.doc", replace starlevels(5 1) se



//////////////////////////////////////////////////////////
//Alternative congruence analyses with different samples
//////////////////////////////////////////////////////////

//Produce Table A12 in the Support Information, column "Conflict issues (5 percent)"
logit Congruent_80pc c.Opinion_majority##c.Salience i.question_id i.member_state if conflict_perc > 0.05
outreg using "Table_A12.doc", replace starlevels(5 1) se
unique question_id if e(sample) == 1

//Produce Table A12 in the Support Information, column "Conflict issues (10 percent)"
logit Congruent_80pc c.Opinion_majority##c.Salience i.question_id i.member_state if conflict_perc > 0.10
outreg using "Table_A12.doc", merge starlevels(5 1) se
unique question_id if e(sample) == 1

//Produce Table A12 in the Support Information, column "Conflict issues (20 percent)"
logit Congruent_80pc c.Opinion_majority##c.Salience i.question_id i.member_state if conflict_perc > 0.20
outreg using "Table_A12.doc", merge starlevels(5 1) se
unique question_id if e(sample) == 1



//////////////////////
//Robustness checks
//////////////////////


/*This section contains all analyses (except for Bayes factors) reported in section 9)
in the Supporting Information. First, all checks with regard to the responsiveness analyses
are run. Then, the checks on the congruence analyses follow. */


//*****Responsiveness analyses - full sample*****

//Note that only the Clarke test p-values (from the "signtest" command) are reported in the Supporting Information

//Produce results for Model A-R1 in Table A13, upper part, in the Supporting Information
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)

logit AdoptionBinary_80pc  Opinion_salience_weighted_raw i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R2 in Table A13, upper part, in the Supporting Information
logit AdoptionBinary_50pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
predict xb_eu
gen lnf_eu = AdoptionBinary_50pc*log(xb_eu) + (1-AdoptionBinary_50pc)*log(1-xb_eu)

logit AdoptionBinary_50pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
predict xb_salient
gen lnf_salient = AdoptionBinary_50pc*log(xb_salient) + (1-AdoptionBinary_50pc)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R3 in Table A13, upper part, in the Supporting Information
program mynormal_lf
        version 11.1
        args lnf mu lnsigma
        quietly replace `lnf' = ln(normalden($ML_y1,`mu', exp(`lnsigma')))
end

ml model lf  mynormal_lf  (AdoptionDegree =  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc) (lnsigma:) if member_state == 1
ml max, nolog
predict double xb_reg
gen double lnf_reg = ln(normalden(AdoptionDegree, xb_reg, exp([lnsigma]_b[_cons])))

ml model lf  mynormal_lf  (AdoptionDegree = Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc) (lnsigma:) if member_state == 1
ml max, nolog
predict double xb_reg_eu
gen double lnf_reg_eu = ln(normalden(AdoptionDegree, xb_reg_eu, exp([lnsigma]_b[_cons])))

signtest lnf_reg = lnf_reg_eu if member_state == 1 & e(sample) == 1
program drop mynormal_lf
drop lnf* xb*


//Produce results for Model A-R4 in Table A13, upper part, in the Supporting Information
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & Problem == "No"
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)

logit AdoptionBinary_80pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & Problem == "No"
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R5 in Table A13, upper part, in the Supporting Information
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & Flipped == "No"
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)

logit AdoptionBinary_80pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & Flipped == "No"
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R6 in Table A13, upper part, in the Supporting Information
logit AdoptionBinary_5halfyears Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
predict xb_eu
gen lnf_eu = AdoptionBinary_5halfyears*log(xb_eu) + (1-AdoptionBinary_5halfyears)*log(1-xb_eu)

logit AdoptionBinary_5halfyears  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 
predict xb_salient
gen lnf_salient = AdoptionBinary_5halfyears*log(xb_salient) + (1-AdoptionBinary_5halfyears)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R7 in Table A13, upper part, in the Supporting Information
logit AdoptionBinary_5years Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1
predict xb_eu
gen lnf_eu = AdoptionBinary_5years*log(xb_eu) + (1-AdoptionBinary_5years)*log(1-xb_eu)

logit AdoptionBinary_5years  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 
predict xb_salient
gen lnf_salient = AdoptionBinary_5years*log(xb_salient) + (1-AdoptionBinary_5years)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//*****Responsiveness analyses - sample of conflict issues*****

//Note that only the Clarke test p-values (from the "signtest" command) are reported in the Supporting Information

//Produce results for Model A-R1 in Table A13, lower part, in the Supporting Information
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)

logit AdoptionBinary_80pc  Opinion_salience_weighted_raw i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R2 in Table A13, lower part, in the Supporting Information
logit AdoptionBinary_50pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
predict xb_eu
gen lnf_eu = AdoptionBinary_50pc*log(xb_eu) + (1-AdoptionBinary_50pc)*log(1-xb_eu)

logit AdoptionBinary_50pc Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
predict xb_salient
gen lnf_salient = AdoptionBinary_50pc*log(xb_salient) + (1-AdoptionBinary_50pc)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R3 in Table A13, lower part, in the Supporting Information
program mynormal_lf
        version 11.1
        args lnf mu lnsigma
        quietly replace `lnf' = ln(normalden($ML_y1,`mu', exp(`lnsigma')))
end

ml model lf  mynormal_lf  (AdoptionDegree =  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc) (lnsigma:) if member_state == 1 & conflict_perc > 0.15
ml max, nolog
predict double xb_reg
gen double lnf_reg = ln(normalden(AdoptionDegree, xb_reg, exp([lnsigma]_b[_cons])))

ml model lf  mynormal_lf  (AdoptionDegree = Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc) (lnsigma:) if member_state == 1 & conflict_perc > 0.15
ml max, nolog
predict double xb_reg_eu
gen double lnf_reg_eu = ln(normalden(AdoptionDegree, xb_reg_eu, exp([lnsigma]_b[_cons])))

signtest lnf_reg = lnf_reg_eu if member_state == 1 & e(sample) == 1
program drop mynormal_lf
drop lnf* xb*


//Produce results for Model A-R4 in Table A13, lower part, in the Supporting Information
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & Problem == "No" & conflict_perc > 0.15
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)

logit AdoptionBinary_80pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & Problem == "No" & conflict_perc > 0.15
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R5 in Table A13, lower part, in the Supporting Information
logit AdoptionBinary_80pc Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & Flipped == "No" & conflict_perc > 0.15
predict xb_eu
gen lnf_eu = AdoptionBinary_80pc*log(xb_eu) + (1-AdoptionBinary_80pc)*log(1-xb_eu)

logit AdoptionBinary_80pc  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & Flipped == "No" & conflict_perc > 0.15
predict xb_salient
gen lnf_salient = AdoptionBinary_80pc*log(xb_salient) + (1-AdoptionBinary_80pc)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R6 in Table A13, lower part, in the Supporting Information
logit AdoptionBinary_5halfyears Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
predict xb_eu
gen lnf_eu = AdoptionBinary_5halfyears*log(xb_eu) + (1-AdoptionBinary_5halfyears)*log(1-xb_eu)

logit AdoptionBinary_5halfyears  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
predict xb_salient
gen lnf_salient = AdoptionBinary_5halfyears*log(xb_salient) + (1-AdoptionBinary_5halfyears)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//Produce results for Model A-R7 in Table A13, lower part, in the Supporting Information
logit AdoptionBinary_5years Opinion_eu_wide i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
predict xb_eu
gen lnf_eu = AdoptionBinary_5years*log(xb_eu) + (1-AdoptionBinary_5years)*log(1-xb_eu)

logit AdoptionBinary_5years  Opinion_salience_weighted i.EUCompetenceLevel i.Unanimity_enc if member_state == 1 & conflict_perc > 0.15
predict xb_salient
gen lnf_salient = AdoptionBinary_5years*log(xb_salient) + (1-AdoptionBinary_5years)*log(1-xb_salient)

signtest lnf_eu = lnf_salient if member_state == 1 & e(sample) == 1
drop lnf* xb*


//*****Congruence analyses - full sample*****

//Produce results for Model A-C1 in Table A14.1 in the Supporting Information
logit Congruent_50pc c.Opinion_majority##c.Salience i.question_id i.member_state
outreg using "Table_A14_1.doc", replace starlevels(5 1) se

//Produce results for Model A-C2 in Table A14.1 in the Supporting Information
logit Congruent_80pc c.Opinion_majority##c.Salience i.question_id i.member_state if Problem == "No"
outreg using "Table_A14_1.doc", merge starlevels(5 1) se

//Produce results for Model A-C3 in Table A14.1 in the Supporting Information
logit Congruent_80pc c.Opinion_majority##c.Salience i.question_id i.member_state if Flipped == "No"
outreg using "Table_A14_1.doc", merge starlevels(5 1) se

//Produce results for Model A-C4 in Table A14.1 in the Supporting Information
logit Congruent_5halfyears c.Opinion_majority##c.Salience i.question_id i.member_state
outreg using "Table_A14_1.doc", merge starlevels(5 1) se

//Produce results for Model A-C5 in Table A14.1 in the Supporting Information
logit Congruent_5years c.Opinion_majority##c.Salience i.question_id i.member_state
outreg using "Table_A14_1.doc", merge starlevels(5 1) se


//*****Congruence analyses - sample of conflict issues*****

xtset question_id

//Produce results for Model A-C1 in Table A14.2 in the Supporting Information
xtlogit Congruent_50pc c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc i.member_state if conflict_perc > 0.15, re
outreg using "Table_A14_2.doc", replace starlevels(5 1) se

//Produce results for Model A-C2 in Table A14.2 in the Supporting Information
xtlogit Congruent_80pc c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc i.member_state if Problem == "No" & conflict_perc > 0.15, re
outreg using "Table_A14_2.doc", merge starlevels(5 1) se

//Produce results for Model A-C3 in Table A14.2 in the Supporting Information
xtlogit Congruent_80pc c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc i.member_state if Flipped == "No" & conflict_perc > 0.15, re
outreg using "Table_A14_2.doc", merge starlevels(5 1) se

//Produce results for Model A-C4 in Table A14.2 in the Supporting Information
xtlogit Congruent_5halfyears c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc i.member_state if conflict_perc > 0.15, re
outreg using "Table_A14_2.doc", merge starlevels(5 1) se

//Produce results for Model A-C5 in Table A14.2 in the Supporting Information
xtlogit Congruent_5years c.Opinion_majority##c.Salience i.EUCompetenceLevel i.Unanimity_enc i.member_state if conflict_perc > 0.15, re
outreg using "Table_A14_2.doc", merge starlevels(5 1) se



///////////////////////////////////////////
//Placebo test for direction of causality
///////////////////////////////////////////

//Produce results in Table A15 in the Supporting Information
gen time_lag = AdoptionT -  FieldworkStart
label variable time_lag "Days from Fieldwork to Adoption"
xtset question_id
xtlogit Congruent_80pc c.Opinion_majority##c.Salience##c.time_lag i.EUCompetenceLevel i.Unanimity_enc i.member_state if AdoptionDegree >= 80, re
outreg using "Table_A15.doc", replace starlevels(10 5 1 0.1) se



////////////////////////////////////////////////////
//Calculate average within-issue change in opinion
////////////////////////////////////////////////////

//Reload analysis dataset
use "analysis_dataset.dta", clear

//Only retain observations for Austria
drop if member_state != 1

//Pool issues that are very similar (i.e. same matter but only minor differences in question wording)
replace QuestionN = subinstr(QuestionN, " (II)", "", .)
replace QuestionN = subinstr(QuestionN, " (III)", "", .)

//Exclude question id 34 on financial transaction tax, since question format is substantially different from 
//the other questions on the financial transaction tax
drop if question_id == 34

//Exclude question id 236 on further enlargement, since question format is substantially different from 
//the other questions on further enlargement
drop if question_id == 236

//Create indicator of time (1st, 2nd, 3rd ... measurement)
egen time = rank(FieldworkStart), by(QuestionN)

//Drop issues that were only surveyed once
egen max_time = max(time), by(QuestionN)
drop if max_time == 1

//Drop if issues were surveyed twice in the same survey (no real change)
drop if question_id == 104
drop if question_id == 169
replace time = 2 if question_id == 103
replace time = 1 if question_id == 168
drop if time == 1.5

//Sort and define as time-series-cross-section dataset
sort QuestionN time
encode QuestionN, gen(policy)
tsset policy time

//Generate lags of opinion and the fieldwork time
gen lag_opinion = L1.Opinion_eu_wide
gen last_survey = L1.FieldworkStart

//Calculate change in opinion and time from last survey
gen change_opinion = abs(Opinion_eu_wide - lag_opinion)
gen change_time = FieldworkStart - last_survey

//Report descriptive statistics for sample of conflict issues
sum change_opinion if conflict_perc > 0.15, detail
sum change_time if conflict_perc > 0.15, detail
//...mean of change in opinion is about 3 percentage points and mean of days between surveys is 826
//as reported in the article in section "Does Territorial Representation Make a Difference?"


